# -*- coding: utf-8 -*-

# doc/source/conf.py
# Part of Mail Drake, an email server for development and testing.
#
# Copyright © 2006–2017 Ben Finney <ben+python@benfinney.id.au>
#
# This is free software, and you are welcome to redistribute it under
# certain conditions; see the end of this file for copyright
# information, grant of license, and disclaimer of warranty.

# Documentation build configuration file for the Mail Drake project.

# Extension modules to enable.
extensions = [
    'sphinx.ext.viewcode',
]

# Relative path for each directory that contains templates.
templates_path = ['_templates']

# Filename suffixes for source files.
source_suffix = ['.txt']

# Text encoding of source files.
source_encoding = 'utf-8-sig'

# Document name of master table of contents document.
master_doc = 'index'

# Metadata for the project.
project = u'Mail Drake'
copyright = u'2006–2017 Ben Finney <ben+python@benfinney.id.au>'
author = u'Ben Finney'

# The version info for the project you're documenting, acts as replacement for
# |version| and |release|, also used in various other places throughout the
# built documents.
#
import os.path
with open(os.path.join(
	os.path.dirname(os.path.dirname(os.path.dirname(os.path.abspath(__file__)))),
	"VERSION")) as version_datafile:
    release = version_datafile.read().strip()
version = release

# Language codes for content autogenerated by Sphinx.
language = None

# Format to use with ‘strftime’ for build date:
today_fmt = '%Y-%m-%d'

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
exclude_patterns = []

# -- Options for HTML output ----------------------------------------------

# Theme to use for HTML and HTML Help pages.
html_theme = 'haiku'

# Options for the chosen theme.
html_theme_options = {}

# Relative paths of any directories that contain custom themes.
html_theme_path = []

# Name for this set of Sphinx documents.
html_title = u"Mail Drake {version}".format(version=version)

# Shorter title for the navigation bar.  Default is the same as html_title.
#
# html_short_title = None

# Relative path to image file to place at the top of the sidebar.
html_logo = '../images/mail-drake-head.75px.png'

# Relative path to image file to use as a favicon of the docs.
# This image should be a Windows icon (.ico) being 16x16 or 32x32
# pixels large.
#
# html_favicon = None

# Relative paths of any directories that contain custom static files
# (such as style sheets).
html_static_path = ['_static']

# Relative paths of any directories that contain custom files (such as
# robots.txt or .htaccess).
html_extra_path = []

# If not None, a 'Last updated on:' timestamp is inserted at every page
# bottom, using the given strftime format.
# The empty string is equivalent to '%b %d, %Y'.
#
# html_last_updated_fmt = None

# Convert quotes and dashes using SmartyPants?
html_use_smartypants = False

# Custom sidebar templates, maps document names to template names.
#
# html_sidebars = {}

# Additional templates that should be rendered to pages, maps page names to
# template names.
#
# html_additional_pages = {}

# If false, no module index is generated.
#
# html_domain_indices = True

# If false, no index is generated.
#
# html_use_index = True

# If true, the index is split into individual pages for each letter.
#
# html_split_index = False

# Link each page to its reST sources?
html_show_sourcelink = True

# Add footer content “Created using Sphinx”?
html_show_sphinx = True

# Add footer content for copyright information?
html_show_copyright = True

# Base URL from which the HTML is served, for generating OpenSearch metadata.
html_use_opensearch = ''

# File name suffix for HTML files (e.g. ".xhtml").
# html_file_suffix = None

# Language to be used for generating the HTML full-text search index.
# Sphinx supports the following languages:
#   'da', 'de', 'en', 'es', 'fi', 'fr', 'hu', 'it', 'ja'
#   'nl', 'no', 'pt', 'ro', 'ru', 'sv', 'tr', 'zh'
#
# html_search_language = 'en'

# A dictionary with options for the search language support, empty by default.
# 'ja' uses this config value.
# 'zh' user can custom change `jieba` dictionary path.
#
# html_search_options = {'type': 'default'}

# The name of a javascript file (relative to the configuration directory) that
# implements a search results scorer. If empty, the default will be used.
#
# html_search_scorer = 'scorer.js'

# Output file base name for HTML help builder.
htmlhelp_basename = 'MailDrakedoc'

# -- Options for LaTeX output ---------------------------------------------

latex_elements = {
     # The paper size ('letterpaper' or 'a4paper').
     #
     # 'papersize': 'letterpaper',

     # The font size ('10pt', '11pt' or '12pt').
     #
     # 'pointsize': '10pt',

     # Additional stuff for the LaTeX preamble.
     #
     # 'preamble': '',

     # Latex figure (float) alignment
     #
     # 'figure_align': 'htbp',
}

# Grouping the document tree into LaTeX files. List of tuples
# (source start file, target name, title,
#  author, documentclass [howto, manual, or own class]).
latex_documents = [
    (master_doc, 'MailDrake.tex', u'Mail Drake documentation',
     u'Ben Finney', 'manual'),
]

# The name of an image file (relative to this directory) to place at the top of
# the title page.
#
# latex_logo = None

# For "manual" documents, if this is true, then toplevel headings are parts,
# not chapters.
#
# latex_use_parts = False

# If true, show page references after internal links.
#
# latex_show_pagerefs = False

# If true, show URL addresses after external links.
#
# latex_show_urls = False

# Documents to append as an appendix to all manuals.
#
# latex_appendices = []

# It false, will not define \strong, \code, 	itleref, \crossref ... but only
# \sphinxstrong, ..., \sphinxtitleref, ... To help avoid clash with user added
# packages.
#
# latex_keep_old_macro_names = True

# If false, no module index is generated.
#
# latex_domain_indices = True


# -- Options for manual page output ---------------------------------------

# One entry per manual page. List of tuples
# (source start file, name, description, authors, manual section).
man_pages = [
    (master_doc, 'maildrake', u'Mail Drake documentation',
     [author], 1)
]

# If true, show URL addresses after external links.
#
# man_show_urls = False


# -- Options for Texinfo output -------------------------------------------

# Grouping the document tree into Texinfo files. List of tuples
# (source start file, target name, title, author,
#  dir menu entry, description, category)
texinfo_documents = [
    (master_doc, 'MailDrake', u'Mail Drake documentation',
     author, 'MailDrake', 'Email server for development and testing.',
     'Miscellaneous'),
]

# Documents to append as an appendix to all manuals.
#
# texinfo_appendices = []

# If false, no module index is generated.
#
# texinfo_domain_indices = True

# How to display URL addresses: 'footnote', 'no', or 'inline'.
#
# texinfo_show_urls = 'footnote'

# If true, do not generate a @detailmenu in the "Top" node's menu.
#
# texinfo_no_detailmenu = False


# Copyright © 2006–2017 Ben Finney <ben+python@benfinney.id.au>
#
# This is free software: you may copy, modify, and/or distribute this work
# under the terms of the GNU Affero General Public License as published by the
# Free Software Foundation; version 3 of that license or any later version.
# No warranty expressed or implied. See the file ‘LICENSE.AGPL-3’ for details.


# Local Variables:
# coding: utf-8
# mode: python
# End:
# vim: fileencoding=utf-8 filetype=python :
